@@ -12,8 +12,8 @@
 #include "fdb5/database/Archiver.h"
 #include "fdb5/database/Inspector.h"
 
-#include "fdb5/remote/client/ClientConnectionRouter.h"
 #include "fdb5/remote/RemoteFieldLocation.h"
+#include "fdb5/remote/client/ClientConnectionRouter.h"
 
 using namespace fdb5::remote;
 using namespace eckit;
@@ -25,7 +25,7 @@ struct BaseAPIHelper {
 
     typedef T ValueType;
 
-    static size_t bufferSize() { return 1024*1024; }
+    static size_t bufferSize() { return 1024 * 1024; }
     static size_t queueSize() { return 100; }
     static fdb5::remote::Message message() { return msgID; }
 
@@ -37,7 +37,7 @@ using StatsHelper = BaseAPIHelper<fdb5::StatsElement, fdb5::remote::Message::Sta
 
 struct ListHelper : BaseAPIHelper<fdb5::ListElement, fdb5::remote::Message::List> {
 
-    ListHelper(const int depth) : depth_(depth) { }
+    ListHelper(const int depth) : depth_(depth) {}
 
     static fdb5::ListElement valueFromStream(eckit::Stream& s, fdb5::RemoteFDB* fdb) {
         fdb5::ListElement elem(s);
@@ -50,26 +50,31 @@ struct ListHelper : BaseAPIHelper<fdb5::ListElement, fdb5::remote::Message::List
         if (elem.location().uri().scheme() == "fdb") {
             eckit::net::Endpoint fieldLocationEndpoint{elem.location().uri().host(), elem.location().uri().port()};
 
-            std::shared_ptr<const fdb5::FieldLocation> remoteLocation = fdb5::remote::RemoteFieldLocation(fdb->storeEndpoint(fieldLocationEndpoint), static_cast<const RemoteFieldLocation&>(elem.location())).make_shared();
+            std::shared_ptr<const fdb5::FieldLocation> remoteLocation =
+                fdb5::remote::RemoteFieldLocation(fdb->storeEndpoint(fieldLocationEndpoint),
+                                                  static_cast<const RemoteFieldLocation&>(elem.location()))
+                    .make_shared();
             return fdb5::ListElement(elem.keys(), remoteLocation, elem.timestamp());
         }
-        std::shared_ptr<const fdb5::FieldLocation> remoteLocation = fdb5::remote::RemoteFieldLocation(fdb->storeEndpoint(), elem.location()).make_shared();
+        std::shared_ptr<const fdb5::FieldLocation> remoteLocation =
+            fdb5::remote::RemoteFieldLocation(fdb->storeEndpoint(), elem.location()).make_shared();
         return fdb5::ListElement(elem.keys(), remoteLocation, elem.timestamp());
     }
 
     void encodeExtra(eckit::Stream& s) const { s << depth_; }
 
 private:
-    int depth_ {3};
+
+    int depth_{3};
 };
 
 struct AxesHelper : BaseAPIHelper<fdb5::AxesElement, fdb5::remote::Message::Axes> {
     AxesHelper(int level) : level_(level) {}
 
-    void encodeExtra(eckit::Stream& s) const {
-        s << level_;
-    }
+    void encodeExtra(eckit::Stream& s) const { s << level_; }
+
 private:
+
     int level_;
 };
 
@@ -85,15 +90,19 @@ struct InspectHelper : BaseAPIHelper<fdb5::ListElement, fdb5::remote::Message::I
         if (elem.location().uri().scheme() == "fdb") {
             eckit::net::Endpoint fieldLocationEndpoint{elem.location().uri().host(), elem.location().uri().port()};
 
-            std::shared_ptr<const fdb5::FieldLocation> remoteLocation = fdb5::remote::RemoteFieldLocation(fdb->storeEndpoint(fieldLocationEndpoint), static_cast<const RemoteFieldLocation&>(elem.location())).make_shared();
+            std::shared_ptr<const fdb5::FieldLocation> remoteLocation =
+                fdb5::remote::RemoteFieldLocation(fdb->storeEndpoint(fieldLocationEndpoint),
+                                                  static_cast<const RemoteFieldLocation&>(elem.location()))
+                    .make_shared();
             return fdb5::ListElement(elem.keys(), remoteLocation, elem.timestamp());
         }
-        std::shared_ptr<const fdb5::FieldLocation> remoteLocation = fdb5::remote::RemoteFieldLocation(fdb->storeEndpoint(), elem.location()).make_shared();
+        std::shared_ptr<const fdb5::FieldLocation> remoteLocation =
+            fdb5::remote::RemoteFieldLocation(fdb->storeEndpoint(), elem.location()).make_shared();
         return fdb5::ListElement(elem.keys(), remoteLocation, elem.timestamp());
     }
 };
 
-}
+}  // namespace
 
 namespace fdb5 {
 
@@ -118,9 +127,8 @@ const eckit::net::Endpoint& RemoteFDB::storeEndpoint(const eckit::net::Endpoint&
     return it->second;
 }
 
-RemoteFDB::RemoteFDB(const eckit::Configuration& config, const std::string& name):
-    LocalFDB(config, name),
-    Client(eckit::net::Endpoint(config.getString("host"), config.getInt("port")), "") {
+RemoteFDB::RemoteFDB(const eckit::Configuration& config, const std::string& name) :
+    LocalFDB(config, name), Client(eckit::net::Endpoint(config.getString("host"), config.getInt("port")), "") {
 
     eckit::Buffer buf = controlWriteReadResponse(remote::Message::Stores, generateRequestID());
     eckit::MemoryStream s(buf);
@@ -133,7 +141,7 @@ RemoteFDB::RemoteFDB(const eckit::Configuration& config, const std::string& name
     std::vector<std::string> stores;
     std::vector<std::string> fieldLocationEndpoints;
 
-    for (size_t i=0; i<numStores; i++) {
+    for (size_t i = 0; i < numStores; i++) {
         std::string store;
         s >> store;
         size_t numAliases;
@@ -142,29 +150,33 @@ RemoteFDB::RemoteFDB(const eckit::Configuration& config, const std::string& name
         if (numAliases == 0) {
             eckit::net::Endpoint storeEndpoint{store};
             storesReadMapping_[storeEndpoint] = storeEndpoint;
-            LOG_DEBUG_LIB(LibFdb5) << "store endpoint: " << storeEndpoint << " default data location endpoint: " << storeEndpoint << std::endl;
-        } else {
-            for (size_t j=0; j<numAliases; j++) {
+            LOG_DEBUG_LIB(LibFdb5) << "store endpoint: " << storeEndpoint
+                                   << " default data location endpoint: " << storeEndpoint << std::endl;
+        }
+        else {
+            for (size_t j = 0; j < numAliases; j++) {
                 eckit::net::Endpoint alias(s);
                 if (store.empty()) {
                     storesLocalFields_.push_back(alias);
                     localFields.emplace(alias);
-                } else {
+                }
+                else {
                     eckit::net::Endpoint fieldLocationEndpoint{store};
                     storesReadMapping_[fieldLocationEndpoint] = alias;
                 }
-                LOG_DEBUG_LIB(LibFdb5) << "store endpoint: " << alias << " default data location endpoint: " << store << std::endl;
+                LOG_DEBUG_LIB(LibFdb5) << "store endpoint: " << alias << " default data location endpoint: " << store
+                                       << std::endl;
             }
         }
     }
-    for(const auto& s: storesReadMapping_) {
+    for (const auto& s : storesReadMapping_) {
         if (localFields.find(s.second) == localFields.end()) {
             storesArchiveMapping_.push_back(std::make_pair(s.second, s.first));
             stores.push_back(s.second);
             fieldLocationEndpoints.push_back(s.first);
         }
     }
-    for (const auto& s: storesLocalFields_) {
+    for (const auto& s : storesLocalFields_) {
         stores.push_back(s);
         fieldLocationEndpoints.push_back("");
     }
@@ -176,7 +188,7 @@ RemoteFDB::RemoteFDB(const eckit::Configuration& config, const std::string& name
 
     config_.set("stores", stores);
     config_.set("fieldLocationEndpoints", fieldLocationEndpoints);
-    config_.overrideSchema(static_cast<std::string>(controlEndpoint())+"/schema", schema);
+    config_.overrideSchema(static_cast<std::string>(controlEndpoint()) + "/schema", schema);
 }
 
 // -----------------------------------------------------------------------------------------------------
@@ -189,17 +201,18 @@ RemoteFDB::RemoteFDB(const eckit::Configuration& config, const std::string& name
 
 
 template <typename HelperClass>
-auto RemoteFDB::forwardApiCall(const HelperClass& helper, const FDBToolRequest& request) -> APIIterator<typename HelperClass::ValueType> {
+auto RemoteFDB::forwardApiCall(const HelperClass& helper, const FDBToolRequest& request)
+    -> APIIterator<typename HelperClass::ValueType> {
 
-    using ValueType = typename HelperClass::ValueType;
-    using IteratorType = APIIterator<ValueType>;
+    using ValueType     = typename HelperClass::ValueType;
+    using IteratorType  = APIIterator<ValueType>;
     using AsyncIterator = APIAsyncIterator<ValueType>;
 
     // Ensure we have an entry in the message queue before we trigger anything that
     // will result in return messages
 
     uint32_t id = generateRequestID();
-    auto entry = messageQueues_.emplace(id, std::make_shared<MessageQueue>(HelperClass::queueSize()));
+    auto entry  = messageQueues_.emplace(id, std::make_shared<MessageQueue>(HelperClass::queueSize()));
     ASSERT(entry.second);
     std::shared_ptr<MessageQueue> messageQueue(entry.first->second);
 
@@ -219,18 +232,18 @@ auto RemoteFDB::forwardApiCall(const HelperClass& helper, const FDBToolRequest&
         // n.b. Don't worry about catching exceptions in lambda, as
         // this is handled in the AsyncIterator.
         new AsyncIterator([messageQueue, remoteFDB](eckit::Queue<ValueType>& queue) {
-                eckit::Buffer msg{0};
-                while (true) {
-                    if (messageQueue->pop(msg) == -1) {
-                        break;
-                    } else {
-                        MemoryStream s(msg);
-                        queue.emplace(HelperClass::valueFromStream(s, remoteFDB));
-                    }
+            eckit::Buffer msg{0};
+            while (true) {
+                if (messageQueue->pop(msg) == -1) {
+                    break;
                 }
-                // messageQueue goes out of scope --> destructed
-            })
-        );
+                else {
+                    MemoryStream s(msg);
+                    queue.emplace(HelperClass::valueFromStream(s, remoteFDB));
+                }
+            }
+            // messageQueue goes out of scope --> destructed
+        }));
 }
 
 ListIterator RemoteFDB::list(const FDBToolRequest& request, const int depth) {
@@ -322,4 +335,4 @@ bool RemoteFDB::handle(remote::Message message, uint32_t requestID, eckit::Buffe
 
 static FDBBuilder<RemoteFDB> builder("remote");
 
-} // namespace fdb5
+}  // namespace fdb5
