@@ -45,17 +45,16 @@ struct fdb_key_t : public Key {
 
 struct fdb_request_t {
 public:
+
     fdb_request_t() : request_(metkit::mars::MarsRequest()) {}
-    fdb_request_t(std::string str) {
-        request_ = metkit::mars::MarsRequest(str);
-    }
+    fdb_request_t(std::string str) { request_ = metkit::mars::MarsRequest(str); }
     size_t values(const char* name, char** values[]) {
         std::string n(name);
         std::vector<std::string> vv = request_.values(name);
 
         *values = new char*[vv.size()];
         for (size_t i = 0; i < vv.size(); i++) {
-            (*values)[i] = new char[vv[i].size()+1];
+            (*values)[i] = new char[vv[i].size() + 1];
             strncpy((*values)[i], vv[i].c_str(), vv[i].size());
             (*values)[i][vv[i].size()] = '\0';
         }
@@ -66,7 +65,7 @@ public:
         std::vector<std::string> vv;
         Tokenizer parse("/");
 
-        for (int i=0; i<numValues; i++) {
+        for (int i = 0; i < numValues; i++) {
             std::vector<std::string> result;
             parse(values[i], result);
             vv.insert(std::end(vv), std::begin(result), std::end(result));
@@ -75,17 +74,19 @@ public:
     }
     static fdb_request_t* parse(std::string str) {
         fdb_request_t* req = new fdb_request_t();
-        req->request_ = metkit::mars::MarsRequest::parse(str);
+        req->request_      = metkit::mars::MarsRequest::parse(str);
         return req;
     }
     void expand() {
         bool inherit = false;
-        bool strict = true;
+        bool strict  = true;
         metkit::mars::MarsExpension expand(inherit, strict);
         request_ = expand.expand(request_);
     }
     const metkit::mars::MarsRequest request() const { return request_; }
+
 private:
+
     metkit::mars::MarsRequest request_;
 };
 
@@ -107,14 +108,18 @@ struct fdb_split_key_t {
         }
         if (curr_ != level_->end()) {
             ++curr_;
-            if (curr_ == level_->end() && level_ != keys_->end() - 1) { curr_ = (++level_)->begin(); }
+            if (curr_ == level_->end() && level_ != keys_->end() - 1) {
+                curr_ = (++level_)->begin();
+            }
         }
         return *this;
     }
 
     int next() {
         ++(*this);
-        if (curr_ == level_->end()) { return FDB_ITERATION_COMPLETE; }
+        if (curr_ == level_->end()) {
+            return FDB_ITERATION_COMPLETE;
+        }
         return FDB_SUCCESS;
     }
 
@@ -126,11 +131,14 @@ struct fdb_split_key_t {
         *k = key.c_str();
         *v = val.c_str();
 
-        if (level) { *level = level_ - keys_->begin(); }
+        if (level) {
+            *level = level_ - keys_->begin();
+        }
     }
 
 private:  // members
-    const value_type* keys_ {nullptr};
+
+    const value_type* keys_{nullptr};
 
     value_type::const_iterator level_;
 
@@ -139,6 +147,7 @@ private:  // members
 
 struct fdb_listiterator_t {
 public:
+
     fdb_listiterator_t(ListIterator&& iter) : iter_(std::move(iter)), validEl_(false) {}
 
     int next() {
@@ -167,6 +176,7 @@ public:
     }
 
 private:
+
     ListIterator iter_;
     bool validEl_;
     ListElement el_;
@@ -174,6 +184,7 @@ private:
 
 struct fdb_datareader_t {
 public:
+
     long open() {
         ASSERT(dh_);
         return dh_->openForRead();
@@ -208,6 +219,7 @@ public:
     }
 
 private:
+
     DataHandle* dh_;
 };
 
@@ -217,23 +229,23 @@ private:
 
 static std::string g_current_error_str;
 static fdb_failure_handler_t g_failure_handler = nullptr;
-static void* g_failure_handler_context = nullptr;
+static void* g_failure_handler_context         = nullptr;
 
 const char* fdb_error_string(int err) {
     switch (err) {
-    case FDB_SUCCESS:
-        return "Success";
-    case FDB_ERROR_GENERAL_EXCEPTION:
-    case FDB_ERROR_UNKNOWN_EXCEPTION:
-        return g_current_error_str.c_str();
-    case FDB_ITERATION_COMPLETE:
-        return "Iteration complete";
-    default:
-        return "<unknown>";
+        case FDB_SUCCESS:
+            return "Success";
+        case FDB_ERROR_GENERAL_EXCEPTION:
+        case FDB_ERROR_UNKNOWN_EXCEPTION:
+            return g_current_error_str.c_str();
+        case FDB_ITERATION_COMPLETE:
+            return "Iteration complete";
+        default:
+            return "<unknown>";
     };
 }
 
-} // extern "C"
+}  // extern "C"
 
 // Template can't have C linkage
 
@@ -255,21 +267,24 @@ int wrapApiFunction(FN f) {
 
     try {
         return innerWrapFn(f);
-    } catch (Exception& e) {
+    }
+    catch (Exception& e) {
         Log::error() << "Caught exception on C-C++ API boundary: " << e.what() << std::endl;
         g_current_error_str = e.what();
         if (g_failure_handler) {
             g_failure_handler(g_failure_handler_context, FDB_ERROR_GENERAL_EXCEPTION);
         }
         return FDB_ERROR_GENERAL_EXCEPTION;
-    } catch (std::exception& e) {
+    }
+    catch (std::exception& e) {
         Log::error() << "Caught exception on C-C++ API boundary: " << e.what() << std::endl;
         g_current_error_str = e.what();
         if (g_failure_handler) {
             g_failure_handler(g_failure_handler_context, FDB_ERROR_GENERAL_EXCEPTION);
         }
         return FDB_ERROR_GENERAL_EXCEPTION;
-    } catch (...) {
+    }
+    catch (...) {
         Log::error() << "Caught unknown on C-C++ API boundary" << std::endl;
         g_current_error_str = "Unrecognised and unknown exception";
         if (g_failure_handler) {
@@ -281,7 +296,7 @@ int wrapApiFunction(FN f) {
     ASSERT(false);
 }
 
-}
+}  // namespace
 
 extern "C" {
 
@@ -295,7 +310,7 @@ extern "C" {
  * Initialise API
  * @note This is only required if being used from a context where Main()
  *       is not otherwise initialised
-*/
+ */
 int fdb_initialise() {
     return wrapApiFunction([] {
         static bool initialised = false;
@@ -315,29 +330,23 @@ int fdb_initialise() {
 
 int fdb_set_failure_handler(fdb_failure_handler_t handler, void* context) {
     return wrapApiFunction([handler, context] {
-        g_failure_handler = handler;
+        g_failure_handler         = handler;
         g_failure_handler_context = context;
         eckit::Log::info() << "FDB setting failure handler fn." << std::endl;
     });
 }
 
 int fdb_version(const char** version) {
-    return wrapApiFunction([version]{
-        (*version) = fdb5_version_str();
-    });
+    return wrapApiFunction([version] { (*version) = fdb5_version_str(); });
 }
 
 int fdb_vcs_version(const char** sha1) {
-    return wrapApiFunction([sha1]{
-        (*sha1) = fdb5_git_sha1();
-    });
+    return wrapApiFunction([sha1] { (*sha1) = fdb5_git_sha1(); });
 }
 
 
 int fdb_new_handle(fdb_handle_t** fdb) {
-    return wrapApiFunction([fdb] {
-        *fdb = new fdb_handle_t();
-    });
+    return wrapApiFunction([fdb] { *fdb = new fdb_handle_t(); });
 }
 
 int fdb_new_handle_from_yaml(fdb_handle_t** fdb, const char* system_config, const char* user_config) {
@@ -347,7 +356,6 @@ int fdb_new_handle_from_yaml(fdb_handle_t** fdb, const char* system_config, cons
         cfg.expandConfig();
         *fdb = new fdb_handle_t(cfg);
     });
-
 }
 
 int fdb_archive(fdb_handle_t* fdb, fdb_key_t* key, const char* data, size_t length) {
@@ -384,10 +392,8 @@ int fdb_list(fdb_handle_t* fdb, const fdb_request_t* req, fdb_listiterator_t** i
             d = 3;
         }
 
-        std::vector<std::string> minKeySet; // we consider an empty set
-        const FDBToolRequest toolRequest(
-            req ? req->request() : metkit::mars::MarsRequest(),
-            req == nullptr, minKeySet);
+        std::vector<std::string> minKeySet;  // we consider an empty set
+        const FDBToolRequest toolRequest(req ? req->request() : metkit::mars::MarsRequest(), req == nullptr, minKeySet);
 
         *it = new fdb_listiterator_t(fdb->list(toolRequest, duplicates, d));
     });
@@ -409,7 +415,7 @@ int fdb_flush(fdb_handle_t* fdb) {
 }
 
 int fdb_delete_handle(fdb_handle_t* fdb) {
-    return wrapApiFunction([fdb]{
+    return wrapApiFunction([fdb] {
         ASSERT(fdb);
         delete fdb;
     });
@@ -418,12 +424,10 @@ int fdb_delete_handle(fdb_handle_t* fdb) {
 /** ancillary functions for creating/destroying FDB objects */
 
 int fdb_new_key(fdb_key_t** key) {
-    return wrapApiFunction([key] {
-        *key = new fdb_key_t();
-    });
+    return wrapApiFunction([key] { *key = new fdb_key_t(); });
 }
 int fdb_key_add(fdb_key_t* key, const char* param, const char* value) {
-    return wrapApiFunction([key, param, value]{
+    return wrapApiFunction([key, param, value] {
         ASSERT(key);
         ASSERT(param);
         ASSERT(value);
@@ -432,16 +436,14 @@ int fdb_key_add(fdb_key_t* key, const char* param, const char* value) {
 }
 
 int fdb_delete_key(fdb_key_t* key) {
-    return wrapApiFunction([key]{
+    return wrapApiFunction([key] {
         ASSERT(key);
         delete key;
     });
 }
 
 int fdb_new_request(fdb_request_t** req) {
-    return wrapApiFunction([req] {
-        *req = new fdb_request_t("retrieve");
-    });
+    return wrapApiFunction([req] { *req = new fdb_request_t("retrieve"); });
 }
 int fdb_request_add(fdb_request_t* req, const char* param, const char* values[], int numValues) {
     return wrapApiFunction([req, param, values, numValues] {
@@ -459,19 +461,17 @@ int fdb_request_get(fdb_request_t* req, const char* param, char** values[], size
     });
 }
 int fdb_expand_request(fdb_request_t* req) {
-    return wrapApiFunction([req]{
-        req->expand();
-    });
+    return wrapApiFunction([req] { req->expand(); });
 }
 int fdb_delete_request(fdb_request_t* req) {
-    return wrapApiFunction([req]{
+    return wrapApiFunction([req] {
         ASSERT(req);
         delete req;
     });
 }
 
 int fdb_listiterator_next(fdb_listiterator_t* it) {
-    return wrapApiFunction(std::function<int()> {[it] {
+    return wrapApiFunction(std::function<int()>{[it] {
         ASSERT(it);
         return it->next();
     }});
@@ -485,7 +485,7 @@ int fdb_listiterator_attrs(fdb_listiterator_t* it, const char** uri, size_t* off
         it->attrs(uri, off, len);
     });
 }
-int fdb_listiterator_splitkey(fdb_listiterator_t* it, fdb_split_key_t* key){
+int fdb_listiterator_splitkey(fdb_listiterator_t* it, fdb_split_key_t* key) {
     return wrapApiFunction([it, key] {
         ASSERT(it);
         ASSERT(key);
@@ -493,42 +493,40 @@ int fdb_listiterator_splitkey(fdb_listiterator_t* it, fdb_split_key_t* key){
     });
 }
 int fdb_delete_listiterator(fdb_listiterator_t* it) {
-    return wrapApiFunction([it]{
+    return wrapApiFunction([it] {
         ASSERT(it);
         delete it;
     });
 }
 
 int fdb_new_splitkey(fdb_split_key_t** key) {
-    return wrapApiFunction([key] {
-        *key = new fdb_split_key_t();
-    });
+    return wrapApiFunction([key] { *key = new fdb_split_key_t(); });
 }
 
 int fdb_splitkey_next_metadata(fdb_split_key_t* it, const char** key, const char** value, size_t* level) {
-    return wrapApiFunction(std::function<int()> {[it, key, value, level] {
+    return wrapApiFunction(std::function<int()>{[it, key, value, level] {
         ASSERT(it);
         ASSERT(key);
         ASSERT(value);
         const auto stat = it->next();
-        if (stat == FDB_SUCCESS) { it->metadata(key, value, level); }
+        if (stat == FDB_SUCCESS) {
+            it->metadata(key, value, level);
+        }
         return stat;
     }});
 }
 int fdb_delete_splitkey(fdb_split_key_t* key) {
-    return wrapApiFunction([key]{
+    return wrapApiFunction([key] {
         ASSERT(key);
         delete key;
     });
 }
 
 int fdb_new_datareader(fdb_datareader_t** dr) {
-    return wrapApiFunction([dr]{
-        *dr = new fdb_datareader_t();
-    });
+    return wrapApiFunction([dr] { *dr = new fdb_datareader_t(); });
 }
 int fdb_datareader_open(fdb_datareader_t* dr, long* size) {
-    return wrapApiFunction([dr, size]{
+    return wrapApiFunction([dr, size] {
         ASSERT(dr);
         long tmp;
         tmp = dr->open();
@@ -537,32 +535,32 @@ int fdb_datareader_open(fdb_datareader_t* dr, long* size) {
     });
 }
 int fdb_datareader_close(fdb_datareader_t* dr) {
-    return wrapApiFunction([dr]{
+    return wrapApiFunction([dr] {
         ASSERT(dr);
         dr->close();
     });
 }
 int fdb_datareader_tell(fdb_datareader_t* dr, long* pos) {
-    return wrapApiFunction([dr, pos]{
+    return wrapApiFunction([dr, pos] {
         ASSERT(dr);
         ASSERT(pos);
         *pos = dr->tell();
     });
 }
 int fdb_datareader_seek(fdb_datareader_t* dr, long pos) {
-    return wrapApiFunction([dr, pos]{
+    return wrapApiFunction([dr, pos] {
         ASSERT(dr);
         dr->seek(pos);
     });
 }
 int fdb_datareader_skip(fdb_datareader_t* dr, long count) {
-    return wrapApiFunction([dr, count]{
+    return wrapApiFunction([dr, count] {
         ASSERT(dr);
         dr->skip(count);
     });
 }
-int fdb_datareader_read(fdb_datareader_t* dr, void *buf, long count, long* read) {
-    return wrapApiFunction([dr, buf, count, read]{
+int fdb_datareader_read(fdb_datareader_t* dr, void* buf, long count, long* read) {
+    return wrapApiFunction([dr, buf, count, read] {
         ASSERT(dr);
         ASSERT(buf);
         ASSERT(read);
@@ -570,13 +568,13 @@ int fdb_datareader_read(fdb_datareader_t* dr, void *buf, long count, long* read)
     });
 }
 int fdb_datareader_size(fdb_datareader_t* dr, long* size) {
-    return wrapApiFunction([=]{
+    return wrapApiFunction([=] {
         ASSERT(dr);
         *size = dr->size();
     });
 }
 int fdb_delete_datareader(fdb_datareader_t* dr) {
-    return wrapApiFunction([dr]{
+    return wrapApiFunction([dr] {
         ASSERT(dr);
         dr->set(nullptr);
         delete dr;
@@ -585,4 +583,4 @@ int fdb_delete_datareader(fdb_datareader_t* dr) {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // extern "C"
+}  // extern "C"
