@@ -15,7 +15,7 @@
 #ifndef fdb5_config_Config_H
 #define fdb5_config_Config_H
 
-#include <sys/stat.h>   // for mode_t
+#include <sys/stat.h>  // for mode_t
 
 #include <string>
 
@@ -31,9 +31,12 @@ class Schema;
 
 class Config : public eckit::LocalConfiguration {
 public:  // static methods
-    static Config make(const eckit::PathName& path, const eckit::Configuration& userConfig = eckit::LocalConfiguration());
+
+    static Config make(const eckit::PathName& path,
+                       const eckit::Configuration& userConfig = eckit::LocalConfiguration());
 
 public:  // methods
+
     Config();
     Config(const eckit::Configuration& config, const eckit::Configuration& userConfig = eckit::LocalConfiguration());
 
@@ -62,9 +65,11 @@ public:  // methods
     std::vector<Config> getSubConfigs() const;
 
 private:  // methods
+
     void initializeSchemaPath() const;
 
 private:  // members
+
     mutable eckit::PathName schemaPath_;
     mutable bool schemaPathInitialised_;
     std::shared_ptr<eckit::LocalConfiguration> userConfig_;
