@@ -13,6 +13,7 @@
 
 #pragma once
 
+#include "eckit/config/LocalConfiguration.h"
 #include "eckit/utils/Optional.h"
 
 #include "fdb5/database/Engine.h"
@@ -25,13 +26,13 @@ namespace fdb5 {
 
 class DaosEngine : public fdb5::Engine {
 
-public: // methods
+public:  // methods
 
     DaosEngine() {};
 
     static const char* typeName() { return "daos"; }
 
-protected: // methods
+protected:  // methods
 
     std::string name() const override;
 
@@ -42,22 +43,22 @@ protected: // methods
     bool canHandle(const eckit::URI&, const Config&) const override;
 
     std::vector<eckit::URI> visitableLocations(const Key& key, const Config& config) const override;
-    std::vector<eckit::URI> visitableLocations(const metkit::mars::MarsRequest& rq, const Config& config) const override;
+    std::vector<eckit::URI> visitableLocations(const metkit::mars::MarsRequest& rq,
+                                               const Config& config) const override;
 
-    void print( std::ostream &out ) const override { NOTIMP; };
+    void print(std::ostream& out) const override { NOTIMP; };
 
-private: // methods
+private:  // methods
 
     void configureDaos(const Config&) const;
 
-private: // members
+private:  // members
 
     mutable eckit::Optional<eckit::LocalConfiguration> daos_config_;
     fdb5::DaosOID catalogue_kv_{0, 0, DAOS_OT_KV_HASHED, OC_S1};  // take oclass from config
-
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
 
-} // namespace fdb5
+}  // namespace fdb5
