@@ -14,14 +14,11 @@ namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-MoveVisitor::MoveVisitor(const metkit::mars::MarsRequest& request,
-                         const eckit::URI& dest) :
-    EntryVisitor(),
-    request_(request),
-    dest_(dest) {}
+MoveVisitor::MoveVisitor(const metkit::mars::MarsRequest& request, const eckit::URI& dest) :
+    EntryVisitor(), request_(request), dest_(dest) {}
 
 MoveVisitor::~MoveVisitor() {}
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
