@@ -19,8 +19,8 @@
 #include <iosfwd>
 
 #include "eckit/memory/NonCopyable.h"
-#include "fdb5/database/Catalogue.h"
 #include "eckit/types/Types.h"
+#include "fdb5/database/Catalogue.h"
 
 namespace metkit::mars {
 class MarsRequest;
@@ -37,7 +37,7 @@ class Schema;
 
 class ReadVisitor : public eckit::NonCopyable {
 
-public: // methods
+public:  // methods
 
     ReadVisitor() : catalogue_(nullptr) {}
 
@@ -50,30 +50,27 @@ public: // methods
     // Once we have selected a database, return its schema. Used for further iteration.
     virtual const Schema& databaseSchema() const = 0;
 
-    virtual void values(const metkit::mars::MarsRequest &request,
-                        const std::string &keyword,
-                        const TypesRegistry &registry,
-                        eckit::StringList &values) = 0;
+    virtual void values(const metkit::mars::MarsRequest& request, const std::string& keyword,
+                        const TypesRegistry& registry, eckit::StringList& values) = 0;
 
-protected: // methods
+protected:  // methods
 
-    virtual void print( std::ostream &out ) const = 0;
+    virtual void print(std::ostream& out) const = 0;
 
-protected: // members
+protected:  // members
 
     CatalogueReader* catalogue_;
 
-private: // members
+private:  // members
 
-    friend std::ostream &operator<<(std::ostream &s, const ReadVisitor &x) {
+    friend std::ostream& operator<<(std::ostream& s, const ReadVisitor& x) {
         x.print(s);
         return s;
     }
-
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
 #endif
