@@ -23,11 +23,7 @@ namespace fdb5 {
 
 struct LustreStripe {
 
-    LustreStripe(unsigned int count, size_t size) :
-        count_(count),
-        size_(size)
-    {
-    }
+    LustreStripe(unsigned int count, size_t size) : count_(count), size_(size) {}
 
     unsigned int count_;
     size_t size_;
@@ -49,4 +45,4 @@ bool fdb5LustreapiSupported();
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
