@@ -10,24 +10,24 @@
 
 #include <vector>
 
-#include "eckit/log/Timer.h"
-#include "eckit/log/Plural.h"
 #include "eckit/log/Bytes.h"
-#include "eckit/log/Seconds.h"
+#include "eckit/log/Plural.h"
 #include "eckit/log/Progress.h"
+#include "eckit/log/Seconds.h"
+#include "eckit/log/Timer.h"
 
 #include "eckit/utils/Tokenizer.h"
 
-#include "eckit/message/Reader.h"
 #include "eckit/message/Message.h"
+#include "eckit/message/Reader.h"
 
-#include "metkit/mars/MarsParser.h"
 #include "metkit/mars/MarsExpension.h"
+#include "metkit/mars/MarsParser.h"
 #include "metkit/mars/MarsRequest.h"
 
 #include "fdb5/LibFdb5.h"
-#include "fdb5/message/MessageArchiver.h"
 #include "fdb5/database/ArchiveVisitor.h"
+#include "fdb5/message/MessageArchiver.h"
 
 // For HAVE_FAIL_ON_CCSDS
 #include "metkit/metkit_config.h"
@@ -43,7 +43,7 @@ std::vector<metkit::mars::MarsRequest> str_to_requests(const std::string& str) {
 
     // parse requests
 
-    std::string rs = std::string("retrieve,")  + str;
+    std::string rs = std::string("retrieve,") + str;
 
     LOG_DEBUG_LIB(LibFdb5) << "Parsing request string : " << rs << std::endl;
 
@@ -74,7 +74,8 @@ std::vector<metkit::mars::MarsRequest> str_to_requests(const std::string& str) {
 
 std::vector<metkit::mars::MarsRequest> make_filter_requests(const std::string& str) {
 
-    if(str.empty()) return {};
+    if (str.empty())
+        return {};
 
     std::set<std::string> keys = Key::parse(str).keys();  //< keys to filter from that request
 
@@ -89,18 +90,12 @@ std::vector<metkit::mars::MarsRequest> make_filter_requests(const std::string& s
     return r;
 }
 
-}
+}  // namespace
 
 //----------------------------------------------------------------------------------------------------------------------
 
 MessageArchiver::MessageArchiver(const fdb5::Key& key, bool completeTransfers, bool verbose, const Config& config) :
-    MessageDecoder(),
-    fdb_(config),
-    key_(key),
-    completeTransfers_(completeTransfers),
-    verbose_(verbose)
-{
-}
+    MessageDecoder(), fdb_(config), key_(key), completeTransfers_(completeTransfers), verbose_(verbose) {}
 
 void MessageArchiver::filters(const std::string& include, const std::string& exclude) {
     include_ = make_filter_requests(include);
@@ -116,9 +111,9 @@ void MessageArchiver::modifiers(const std::string& modify) {
 
     // Log::info() << "pairs : " << pairs << std::endl;
 
-    for(auto& pair: pairs) {
+    for (auto& pair : pairs) {
         std::vector<std::string> kv = equal.tokenize(pair);
-        if(kv.size() != 2)
+        if (kv.size() != 2)
             throw eckit::BadValue("Invalid key-value pair " + pair);
         // Log::info() << "kv : " << kv[0] << " = " << kv[1] << std::endl;
         modifiers_[kv[0]] = kv[1];
@@ -132,7 +127,8 @@ eckit::message::Message MessageArchiver::transform(eckit::message::Message& msg)
 
 static bool matchAny(const metkit::mars::MarsRequest& f, const std::vector<metkit::mars::MarsRequest>& v) {
     for (auto r = v.begin(); r != v.end(); ++r) {
-        if(f.matches(*r)) return true;
+        if (f.matches(*r))
+            return true;
     }
     return false;
 }
@@ -150,11 +146,13 @@ bool MessageArchiver::filterOut(const Key& k) const {
 
     // filter includes
 
-    if(include_.size() && not matchAny(field, include_)) return out;
+    if (include_.size() && not matchAny(field, include_))
+        return out;
 
     // filter excludes
 
-    if(exclude_.size() && matchAny(field, exclude_)) return out;
+    if (exclude_.size() && matchAny(field, exclude_))
+        return out;
 
     // datum wasn't filtered out
 
@@ -167,7 +165,7 @@ eckit::Length MessageArchiver::archive(eckit::DataHandle& source) {
 
     eckit::message::Reader reader(source);
 
-    size_t count = 0;
+    size_t count      = 0;
     size_t total_size = 0;
 
     eckit::Progress progress("FDB archive", 0, source.estimate());
@@ -176,11 +174,11 @@ eckit::Length MessageArchiver::archive(eckit::DataHandle& source) {
 
         eckit::message::Message msg;
 
-        while ( (msg = reader.next()) ) {
+        while ((msg = reader.next())) {
 
 #ifdef metkit_HAVE_FAIL_ON_CCSDS
 
-            if(msg.getString("packingType") == "grid_ccsds") {
+            if (msg.getString("packingType") == "grid_ccsds") {
                 throw eckit::SeriousBug("grid_ccsds is disabled");
             }
 
@@ -191,8 +189,7 @@ eckit::Length MessageArchiver::archive(eckit::DataHandle& source) {
             messageToKey(msg, key);
 
             LOG_DEBUG_LIB(LibFdb5) << "Archiving message "
-                                   << " key: " << key << " length:" << msg.length()
-                                   << std::endl;
+                                   << " key: " << key << " length:" << msg.length() << std::endl;
 
             ASSERT(key.match(key_));
 
@@ -207,7 +204,8 @@ eckit::Length MessageArchiver::archive(eckit::DataHandle& source) {
 
             if (verbose_) {
                 Log::info() << "Archiving " << key << std::endl;
-            } else {
+            }
+            else {
                 LOG_DEBUG_LIB(LibFdb5) << "Archiving " << key << std::endl;
             }
 
@@ -219,13 +217,14 @@ eckit::Length MessageArchiver::archive(eckit::DataHandle& source) {
 
             // flush();
         }
-
-    } catch (...) {
+    }
+    catch (...) {
 
         if (completeTransfers_) {
             eckit::Log::error() << "Exception received. Completing transfer." << std::endl;
             // Consume rest of datahandle otherwise client retries for ever
-            while ( reader.next() ) { /* empty */ }
+            while (reader.next()) { /* empty */
+            }
         }
         throw;
     }
@@ -246,4 +245,4 @@ void MessageArchiver::flush() {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
