@@ -14,9 +14,9 @@
  */
 
 #include "fdb5/remote/RemoteFieldLocation.h"
-#include "fdb5/remote/client/RemoteStore.h"
-#include "fdb5/remote/client/ClientConnectionRouter.h"
 #include "fdb5/LibFdb5.h"
+#include "fdb5/remote/client/ClientConnectionRouter.h"
+#include "fdb5/remote/client/RemoteStore.h"
 
 #include "eckit/exception/Exceptions.h"
 #include "eckit/filesystem/URIManager.h"
@@ -25,17 +25,17 @@
 namespace fdb5 {
 namespace remote {
 
-::eckit::ClassSpec RemoteFieldLocation::classSpec_ = {&FieldLocation::classSpec(), "RemoteFieldLocation",};
+::eckit::ClassSpec RemoteFieldLocation::classSpec_ = {
+    &FieldLocation::classSpec(),
+    "RemoteFieldLocation",
+};
 ::eckit::Reanimator<RemoteFieldLocation> RemoteFieldLocation::reanimator_;
 
 //----------------------------------------------------------------------------------------------------------------------
 
 RemoteFieldLocation::RemoteFieldLocation(const eckit::net::Endpoint& endpoint, const FieldLocation& remoteLocation) :
-    FieldLocation(
-        eckit::URI("fdb", remoteLocation.uri(), endpoint.hostname(),  endpoint.port()),
-        remoteLocation.offset(),
-        remoteLocation.length(),
-        remoteLocation.remapKey()) {
+    FieldLocation(eckit::URI("fdb", remoteLocation.uri(), endpoint.hostname(), endpoint.port()),
+                  remoteLocation.offset(), remoteLocation.length(), remoteLocation.remapKey()) {
 
     ASSERT(remoteLocation.uri().scheme() != "fdb");
     if (!remoteLocation.uri().scheme().empty()) {
@@ -46,28 +46,24 @@ RemoteFieldLocation::RemoteFieldLocation(const eckit::net::Endpoint& endpoint, c
     }
 }
 
-RemoteFieldLocation::RemoteFieldLocation(const eckit::net::Endpoint& endpoint, const RemoteFieldLocation& remoteLocation) :
-    FieldLocation(
-        eckit::URI("fdb", remoteLocation.uri(), endpoint.hostname(),  endpoint.port()),
-        remoteLocation.offset(),
-        remoteLocation.length(),
-        remoteLocation.remapKey()) {}
+RemoteFieldLocation::RemoteFieldLocation(const eckit::net::Endpoint& endpoint,
+                                         const RemoteFieldLocation& remoteLocation) :
+    FieldLocation(eckit::URI("fdb", remoteLocation.uri(), endpoint.hostname(), endpoint.port()),
+                  remoteLocation.offset(), remoteLocation.length(), remoteLocation.remapKey()) {}
 
-RemoteFieldLocation::RemoteFieldLocation(const eckit::URI& uri) :
-    FieldLocation(uri) {
+RemoteFieldLocation::RemoteFieldLocation(const eckit::URI& uri) : FieldLocation(uri) {
 
     ASSERT(uri.scheme() == "fdb");
 }
 
-RemoteFieldLocation::RemoteFieldLocation(const eckit::URI& uri, const eckit::Offset& offset, const eckit::Length& length, const Key& remapKey) :
+RemoteFieldLocation::RemoteFieldLocation(const eckit::URI& uri, const eckit::Offset& offset,
+                                         const eckit::Length& length, const Key& remapKey) :
     FieldLocation(uri, offset, length, remapKey) {
 
     ASSERT(uri.scheme() == "fdb");
 }
 
-RemoteFieldLocation::RemoteFieldLocation(eckit::Stream& s) :
-    FieldLocation(s) {
-}
+RemoteFieldLocation::RemoteFieldLocation(eckit::Stream& s) : FieldLocation(s) {}
 
 RemoteFieldLocation::RemoteFieldLocation(const RemoteFieldLocation& rhs) :
     FieldLocation(rhs.uri_, rhs.offset_, rhs.length_, rhs.remapKey_) {}
@@ -78,22 +74,22 @@ std::shared_ptr<const FieldLocation> RemoteFieldLocation::make_shared() const {
 }
 
 eckit::DataHandle* RemoteFieldLocation::dataHandle() const {
-    
+
     eckit::Log::debug<fdb5::LibFdb5>() << "RemoteFieldLocation::dataHandle for location: ";
     dump(eckit::Log::debug<fdb5::LibFdb5>());
     eckit::Log::debug<fdb5::LibFdb5>() << std::endl;
 
     RemoteStore& store = RemoteStore::get(uri_);
-    
-    const std::string scheme = uri_.query("internalScheme");
+
+    const std::string scheme   = uri_.query("internalScheme");
     const std::string hostport = uri_.query("internalHost");
     eckit::URI remote;
     if (hostport.empty()) {
-        remote = eckit::URI(scheme, uri_, "",  -1);
+        remote = eckit::URI(scheme, uri_, "", -1);
     }
     else {
         eckit::net::Endpoint endpoint{hostport};
-        remote = eckit::URI(scheme, uri_, endpoint.host(),  endpoint.port());
+        remote = eckit::URI(scheme, uri_, endpoint.host(), endpoint.port());
         remote.query("internalHost", "");
     }
     remote.query("internalScheme", "");
@@ -129,13 +125,12 @@ class FdbURIManager : public eckit::URIManager {
 
     eckit::DataHandle* newReadHandle(const eckit::URI& f) override { return f.path().fileHandle(); }
 
-    eckit::DataHandle* newReadHandle(const eckit::URI& f, const eckit::OffsetList& ol, const eckit::LengthList& ll) override {
+    eckit::DataHandle* newReadHandle(const eckit::URI& f, const eckit::OffsetList& ol,
+                                     const eckit::LengthList& ll) override {
         return f.path().partHandle(ol, ll);
     }
 
-    eckit::PathName path(const eckit::URI& u) const override {
-        return eckit::PathName{u.name()};
-    }
+    eckit::PathName path(const eckit::URI& u) const override { return eckit::PathName{u.name()}; }
 
     std::string asString(const eckit::URI& uri) const override {
         std::string q = uri.query();
@@ -147,11 +142,13 @@ class FdbURIManager : public eckit::URIManager {
 
         return uri.name() + q + f;
     }
+
 public:
+
     FdbURIManager(const std::string& name) : eckit::URIManager(name) {}
 };
 
 static FdbURIManager manager_fdb_file("fdb");
 
-} // namespace remote
-} // namespace fdb5
\ No newline at end of file
+}  // namespace remote
+}  // namespace fdb5
\ No newline at end of file
