@@ -34,14 +34,12 @@ class DataWriteRequest;
 
 class ClientConnection : protected Connection {
 
-public: // methods
+public:  // methods
+
     ~ClientConnection() override;
 
-    std::future<eckit::Buffer> controlWrite(const Client& client,
-                                            Message       msg,
-                                            uint32_t      requestID,
-                                            bool /*dataListener*/,
-                                            PayloadList payload = {}) const;
+    std::future<eckit::Buffer> controlWrite(const Client& client, Message msg, uint32_t requestID,
+                                            bool /*dataListener*/, PayloadList payload = {}) const;
 
     void dataWrite(Client& client, Message msg, uint32_t requestID, PayloadList payloads = {});
 
@@ -55,7 +53,7 @@ public: // methods
     const eckit::net::Endpoint& controlEndpoint() const;
     const std::string& defaultEndpoint() const { return defaultEndpoint_; }
 
-private: // methods
+private:  // methods
 
     friend class ClientConnectionRouter;
 
@@ -81,7 +79,7 @@ private: // methods
 
     const eckit::net::TCPSocket& dataSocket() const override { return dataClient_; }
 
-private: // members
+private:  // members
 
     eckit::SessionID sessionID_;
 
