@@ -1,9 +1,10 @@
 #include "fdb5/remote/client/ClientConnectionRouter.h"
 
-namespace{
+namespace {
 
 class ConnectionError : public eckit::Exception {
 public:
+
     ConnectionError();
     ConnectionError(const eckit::net::Endpoint&);
 
@@ -23,39 +24,43 @@ ConnectionError::ConnectionError(const eckit::net::Endpoint& endpoint) {
     reason(s.str());
     eckit::Log::status() << what() << std::endl;
 }
-}
+}  // namespace
 namespace fdb5::remote {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-ClientConnection& ClientConnectionRouter::connection(const eckit::net::Endpoint& endpoint, const std::string& defaultEndpoint) {
+ClientConnection& ClientConnectionRouter::connection(const eckit::net::Endpoint& endpoint,
+                                                     const std::string& defaultEndpoint) {
 
     std::lock_guard<std::mutex> lock(connectionMutex_);
 
     auto it = connections_.find(endpoint);
     if (it != connections_.end()) {
         return *(it->second);
-    } else {
+    }
+    else {
         ClientConnection* clientConnection = new ClientConnection{endpoint, defaultEndpoint};
         if (clientConnection->connect()) {
             auto it = (connections_.emplace(endpoint, std::unique_ptr<ClientConnection>(clientConnection))).first;
             return *(it->second);
-        } else {
+        }
+        else {
             delete clientConnection;
             throw ConnectionError(endpoint);
         }
     }
 }
 
-ClientConnection& ClientConnectionRouter::connection(const std::vector<std::pair<eckit::net::Endpoint, std::string>>& endpoints) {
+ClientConnection& ClientConnectionRouter::connection(
+    const std::vector<std::pair<eckit::net::Endpoint, std::string>>& endpoints) {
 
     std::vector<std::pair<eckit::net::Endpoint, std::string>> fullEndpoints{endpoints};
 
     std::lock_guard<std::mutex> lock(connectionMutex_);
-    while (fullEndpoints.size()>0) {
+    while (fullEndpoints.size() > 0) {
 
         // select a random endpoint
-        size_t idx = std::rand() % fullEndpoints.size();
+        size_t idx                    = std::rand() % fullEndpoints.size();
         eckit::net::Endpoint endpoint = fullEndpoints.at(idx).first;
 
         // look for the selected endpoint
@@ -63,8 +68,9 @@ ClientConnection& ClientConnectionRouter::connection(const std::vector<std::pair
         if (it != connections_.end()) {
             return *(it->second);
         }
-        else { // not yet there, trying to connect
-             std::unique_ptr<ClientConnection> clientConnection =  std::unique_ptr<ClientConnection>(new ClientConnection{endpoint, fullEndpoints.at(idx).second});
+        else {  // not yet there, trying to connect
+            std::unique_ptr<ClientConnection> clientConnection =
+                std::unique_ptr<ClientConnection>(new ClientConnection{endpoint, fullEndpoints.at(idx).second});
             if (clientConnection->connect(true)) {
                 auto it = (connections_.emplace(endpoint, std::move(clientConnection))).first;
                 return *(it->second);
@@ -72,7 +78,7 @@ ClientConnection& ClientConnectionRouter::connection(const std::vector<std::pair
         }
 
         // unable to connect to "endpoint", remove it and try again
-        if (idx != fullEndpoints.size()-1) { // swap with the last element
+        if (idx != fullEndpoints.size() - 1) {  // swap with the last element
             fullEndpoints[idx] = std::move(fullEndpoints.back());
         }
         fullEndpoints.pop_back();
@@ -90,8 +96,7 @@ void ClientConnectionRouter::deregister(ClientConnection& connection) {
     }
 }
 
-ClientConnectionRouter& ClientConnectionRouter::instance()
-{
+ClientConnectionRouter& ClientConnectionRouter::instance() {
     static ClientConnectionRouter router;
     return router;
 }
@@ -103,13 +108,13 @@ void ClientConnectionRouter::teardown(std::exception_ptr e) {
             std::rethrow_exception(e);
         }
     }
-    catch(const std::exception& e) {
+    catch (const std::exception& e) {
         eckit::Log::error() << "error: " << e.what();
     }
 
     std::lock_guard<std::mutex> lock(connectionMutex_);
 
-    for (const auto& [endp,conn] : connections_) {
+    for (const auto& [endp, conn] : connections_) {
         if (conn) {
             eckit::Log::warning() << "closing connection " << endp << std::endl;
             conn->teardown();
