@@ -26,9 +26,10 @@ namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-class MatchHidden : public Matcher{
+class MatchHidden : public Matcher {
+
+public:  // methods
 
-public: // methods
     MatchHidden(std::string def);
 
     MatchHidden(eckit::Stream& s);
@@ -40,30 +41,31 @@ public: // methods
     void dump(std::ostream& s, const std::string& keyword, const TypesRegistry& registry) const override;
 
     const eckit::ReanimatorBase& reanimator() const override { return reanimator_; }
-    static const eckit::ClassSpec&  classSpec() { return classSpec_; }
+    static const eckit::ClassSpec& classSpec() { return classSpec_; }
+
+private:  // methods
 
-private: // methods
     void encode(eckit::Stream& stream) const override;
 
     bool optional() const override { return true; }
 
-    const std::string &value(const Key&, const std::string& keyword) const override;
-    const std::vector<std::string>& values(const metkit::mars::MarsRequest& rq, const std::string& keyword) const override;
+    const std::string& value(const Key&, const std::string& keyword) const override;
+    const std::vector<std::string>& values(const metkit::mars::MarsRequest& rq,
+                                           const std::string& keyword) const override;
     const std::string& defaultValue() const override;
 
     void print(std::ostream& out) const override;
 
-private: // members
+private:  // members
 
     static eckit::ClassSpec classSpec_;
     static eckit::Reanimator<MatchHidden> reanimator_;
 
     std::vector<std::string> default_;
-
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
 #endif
