@@ -16,9 +16,9 @@
 #ifndef fdb5_FileSpaceHandler_H
 #define fdb5_FileSpaceHandler_H
 
-#include "eckit/utils/Regex.h"
-#include "eckit/types/Types.h"
 #include "eckit/memory/NonCopyable.h"
+#include "eckit/types/Types.h"
+#include "eckit/utils/Regex.h"
 
 #include "fdb5/toc/Root.h"
 
@@ -33,7 +33,7 @@ class FileSpaceHandlerInstance;
 
 class FileSpaceHandler : private eckit::NonCopyable {
 
-public: // methods
+public:  // methods
 
     static const FileSpaceHandler& lookup(const std::string& name);
     static void regist(const std::string& name, FileSpaceHandlerInstance* h);
@@ -43,10 +43,9 @@ public: // methods
 
     virtual eckit::PathName selectFileSystem(const Key& key, const FileSpace& fs) const = 0;
 
-protected: // methods
+protected:  // methods
 
     FileSpaceHandler();
-
 };
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -68,21 +67,21 @@ private:
 
     std::string name_;
     mutable FileSpaceHandler* instance_;
-
 };
 
-template<class T>
+template <class T>
 class FileSpaceHandlerRegister : public FileSpaceHandlerInstance {
 public:
-    FileSpaceHandlerRegister(const std::string& name) : FileSpaceHandlerInstance(name) {
-    }
+
+    FileSpaceHandlerRegister(const std::string& name) : FileSpaceHandlerInstance(name) {}
 
 private:
+
     FileSpaceHandler* make() const override { return new T(); }
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
 #endif
