@@ -51,30 +51,22 @@ struct UriStoreWrapper {
 //----------------------------------------------------------------------------------------------------------------------
 
 
-class TocIndex :
-        private UriStoreWrapper,
-        public IndexBase {
+class TocIndex : private UriStoreWrapper, public IndexBase {
 
-public: // types
+public:  // types
 
-    enum Mode { WRITE, READ };
+    enum Mode {
+        WRITE,
+        READ
+    };
 
-public: // methods
+public:  // methods
 
-    TocIndex(const Key& key,
-             const Catalogue& catalogue,
-             const eckit::PathName &path,
-             off_t offset,
-             Mode mode,
+    TocIndex(const Key& key, const eckit::PathName& path, off_t offset, Mode mode,
              const std::string& type = defaulType());
 
-    TocIndex(eckit::Stream &,
-             const Catalogue& catalogue,
-             const int version,
-             const eckit::PathName &directory,
-             const eckit::PathName &path,
-             off_t offset,
-             bool preloadBTree=false);
+    TocIndex(eckit::Stream&, const int version, const eckit::PathName& directory, const eckit::PathName& path,
+             off_t offset, bool preloadBTree = false);
 
     ~TocIndex() override;
 
@@ -86,7 +78,8 @@ public: // methods
     void flock() const override;
     void funlock() const override;
 
-private: // methods
+private:  // methods
+
     const IndexLocation& location() const override { return location_; }
 
     std::vector<eckit::URI> dataURIs() const override;
@@ -99,20 +92,20 @@ private: // methods
 
     void visit(IndexLocationVisitor& visitor) const override;
 
-    bool get(const Key& key, const Key& remapKey, Field& field ) const override;
-    void add(const Key& key, const Field& field ) override;
+    bool get(const Key& key, const Key& remapKey, Field& field) const override;
+    void add(const Key& key, const Field& field) override;
     void flush() override;
     void encode(eckit::Stream& s, const int version) const override;
     void entries(EntryVisitor& visitor) const override;
 
-    void print( std::ostream &out ) const override;
+    void print(std::ostream& out) const override;
     void dump(std::ostream& out, const char* indent, bool simple = false, bool dumpFields = false) const override;
 
     IndexStats statistics() const override;
 
-private: // members
+private:  // members
 
-    std::unique_ptr<BTreeIndex>  btree_;
+    std::unique_ptr<BTreeIndex> btree_;
 
     bool dirty_;
 
@@ -135,7 +128,7 @@ private: // members
 struct TocIndexFileSort {
 
     // Return true if first argument is earlier than the second, and false otherwise.
-    bool operator() (const Index& lhs, const Index& rhs) {
+    bool operator()(const Index& lhs, const Index& rhs) {
 
         const TocIndex* idx1 = dynamic_cast<const TocIndex*>(lhs.content());
         const TocIndex* idx2 = dynamic_cast<const TocIndex*>(rhs.content());
@@ -148,7 +141,8 @@ struct TocIndexFileSort {
 
         if (pth1 == pth2) {
             return idx1->offset() < idx2->offset();
-        } else {
+        }
+        else {
             return pth1 < pth2;
         }
     }
@@ -156,6 +150,6 @@ struct TocIndexFileSort {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
 #endif
