@@ -9,6 +9,7 @@
  */
 
 #include "eckit/config/Resource.h"
+
 #include "fdb5/LibFdb5.h"
 #include "fdb5/toc/TocSerialisationVersion.h"
 
@@ -18,33 +19,36 @@ static unsigned getUserEnvSerialisationVersion() {
 
     static unsigned fdbSerialisationVersion =
         eckit::Resource<unsigned>("fdbSerialisationVersion;$FDB5_SERIALISATION_VERSION", 0);
-    
+
     if (fdbSerialisationVersion && fdbSerialisationVersion != TocSerialisationVersion::defaulted()) {
-        LOG_DEBUG_LIB(LibFdb5) << "fdbSerialisationVersion overidde to version: " << fdbSerialisationVersion << std::endl;
+        LOG_DEBUG_LIB(LibFdb5) << "fdbSerialisationVersion overidde to version: " << fdbSerialisationVersion
+                               << std::endl;
     }
-    return fdbSerialisationVersion; // default is 0 (not defined by user/service)
+    return fdbSerialisationVersion;  // default is 0 (not defined by user/service)
 }
 
 TocSerialisationVersion::TocSerialisationVersion(const fdb5::Config& config) {
     static unsigned envVersion = getUserEnvSerialisationVersion();
     if (envVersion) {
         used_ = envVersion;
-    } else {
+    }
+    else {
         static int tocSerialisationVersion = config.getInt("tocSerialisationVersion", 0);
         if (tocSerialisationVersion && tocSerialisationVersion != TocSerialisationVersion::defaulted()) {
-            LOG_DEBUG_LIB(LibFdb5) << "tocSerialisationVersion overidde to version: " << tocSerialisationVersion << std::endl;
+            LOG_DEBUG_LIB(LibFdb5) << "tocSerialisationVersion overidde to version: " << tocSerialisationVersion
+                                   << std::endl;
             used_ = tocSerialisationVersion;
-        } else {
+        }
+        else {
             used_ = defaulted();
         }
     }
 
     bool valid = check(used_, false);
-    if(not valid) {
+    if (not valid) {
         std::ostringstream msg;
-        msg << "Unsupported FDB5 toc serialisation version " << envVersion
-        << " - supported: " << supportedStr()
-        << std::endl;
+        msg << "Unsupported FDB5 toc serialisation version " << envVersion << " - supported: " << supportedStr()
+            << std::endl;
         throw eckit::BadValue(msg.str(), Here());
     }
 }
@@ -95,4 +99,4 @@ bool TocSerialisationVersion::check(unsigned int version, bool throwOnFail) cons
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
