@@ -15,31 +15,31 @@
 #include "eckit/option/CmdArgs.h"
 #include "eckit/option/SimpleOption.h"
 
-#include "metkit/mars/MarsRequest.h"
-#include "metkit/mars/MarsParser.h"
 #include "metkit/mars/MarsExpension.h"
+#include "metkit/mars/MarsParser.h"
+#include "metkit/mars/MarsRequest.h"
 
 #include "fdb5/api/FDB.h"
-#include "fdb5/message/MessageDecoder.h"
 #include "fdb5/io/HandleGatherer.h"
+#include "fdb5/message/MessageDecoder.h"
 #include "fdb5/tools/FDBTool.h"
 
 
 class FDBRead : public fdb5::FDBTool {
-    virtual void execute(const eckit::option::CmdArgs &args);
-    virtual void usage(const std::string &tool) const;
+    virtual void execute(const eckit::option::CmdArgs& args);
+    virtual void usage(const std::string& tool) const;
     virtual int numberOfPositionalArguments() const { return 2; }
-  public:
-    FDBRead(int argc, char **argv): fdb5::FDBTool(argc, argv) {
+
+public:
+
+    FDBRead(int argc, char** argv) : fdb5::FDBTool(argc, argv) {
         options_.push_back(new eckit::option::SimpleOption<bool>("extract", "Extract request from a GRIB file"));
         options_.push_back(new eckit::option::SimpleOption<bool>("raw", "Uses the raw request, without expansion"));
-        options_.push_back(
-                    new eckit::option::SimpleOption<bool>("statistics",
-                                                          "Report timing statistics"));
+        options_.push_back(new eckit::option::SimpleOption<bool>("statistics", "Report timing statistics"));
     }
 };
 
-void FDBRead::usage(const std::string &tool) const {
+void FDBRead::usage(const std::string& tool) const {
     eckit::Log::info() << std::endl
                        << "Usage: " << tool << " request.mars target.grib" << std::endl
                        << "       " << tool << " --raw request.mars target.grib" << std::endl
@@ -48,10 +48,10 @@ void FDBRead::usage(const std::string &tool) const {
     fdb5::FDBTool::usage(tool);
 }
 
-void FDBRead::execute(const eckit::option::CmdArgs &args) {
+void FDBRead::execute(const eckit::option::CmdArgs& args) {
 
     bool extract = args.getBool("extract", false);
-    bool raw = args.getBool("raw", false);
+    bool raw     = args.getBool("raw", false);
 
     std::vector<metkit::mars::MarsRequest> requests;
 
@@ -63,8 +63,8 @@ void FDBRead::execute(const eckit::option::CmdArgs &args) {
 
         fdb5::MessageDecoder decoder;
         requests = decoder.messageToRequests(args(0));
-
-    } else {
+    }
+    else {
         std::ifstream in(args(0).c_str());
         if (in.bad()) {
             throw eckit::ReadError(args(0));
@@ -75,7 +75,8 @@ void FDBRead::execute(const eckit::option::CmdArgs &args) {
         if (raw) {
             for (auto r : parsedRequests)
                 requests.push_back(r);
-        } else {
+        }
+        else {
             metkit::mars::MarsExpension expand(/* inherit */ false);
             requests = expand.expand(parsedRequests);
         }
@@ -102,8 +103,7 @@ void FDBRead::execute(const eckit::option::CmdArgs &args) {
 }
 
 
-int main(int argc, char **argv) {
+int main(int argc, char** argv) {
     FDBRead app(argc, argv);
     return app.start();
 }
-
