@@ -24,7 +24,7 @@ namespace fdb5 {
 
 class TypeMonth : public Type {
 
-public: // methods
+public:  // methods
 
     TypeMonth(const std::string& name, const std::string& type, const std::string& alias = "month");
 
@@ -32,20 +32,16 @@ public: // methods
 
     std::string toKey(const std::string& value) const override;
 
-    virtual void getValues(const metkit::mars::MarsRequest &request,
-                           const std::string &keyword,
-                           eckit::StringList &values,
-                           const Notifier &wind,
-                           const CatalogueReader* cat) const override;
+    virtual void getValues(const metkit::mars::MarsRequest& request, const std::string& keyword,
+                           eckit::StringList& values, const Notifier& wind, const CatalogueReader* cat) const override;
 
-private: // methods
-
-    void print( std::ostream &out ) const override;
+private:  // methods
 
+    void print(std::ostream& out) const override;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
 #endif
