@@ -31,38 +31,36 @@ class Type;
 
 class TypesFactory {
 
-    virtual Type *make(const std::string &keyword) const = 0 ;
+    virtual Type* make(const std::string& keyword) const = 0;
 
 protected:
 
-    TypesFactory(const std::string &);
+    TypesFactory(const std::string&);
     virtual ~TypesFactory();
 
     std::string name_;
 
 public:
 
-    static void list(std::ostream &);
-    static Type *build(const std::string &name, const std::string &keyword);
-
+    static void list(std::ostream&);
+    static Type* build(const std::string& name, const std::string& keyword);
 };
 
 /// Templated specialisation of the self-registering factory,
 /// that does the self-registration, and the construction of each object.
 
-template< class T>
+template <class T>
 class TypeBuilder : public TypesFactory {
 
-    Type *make(const std::string &keyword) const override {
-        return new T(keyword, name_);
-    }
+    Type* make(const std::string& keyword) const override { return new T(keyword, name_); }
 
 public:
-    TypeBuilder(const std::string &name) : TypesFactory(name) {}
+
+    TypeBuilder(const std::string& name) : TypesFactory(name) {}
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace fdb5
+}  // namespace fdb5
 
 #endif
